@@ -103,7 +103,7 @@ func issueKeyFromTuiData(r int, d interface{}) string {
 
 	switch data := d.(type) {
 	case tui.TableData:
-		path = data[r][getKeyColumnIndex(data[0])]
+		path = data.Get(r, data.GetIndex(fieldKey))
 	case tui.PreviewData:
 		path = data.Key
 	}
@@ -151,15 +151,6 @@ func renderPlain(w io.Writer, data tui.TableData) error {
 	return nil
 }
 
-func getKeyColumnIndex(cols []string) int {
-	for i, col := range cols {
-		if col == fieldKey {
-			return i
-		}
-	}
-	return 1
-}
-
 func coloredOut(msg string, clr color.Attribute, attrs ...color.Attribute) string {
 	c := color.New(clr).Add(attrs...)
 	return c.Sprint(msg)
@@ -182,8 +173,8 @@ func gray256(msg string) string {
 }
 
 func shortenAndPad(msg string, limit int) string {
-	if limit >= 3 && len(msg) > limit {
-		return msg[0:limit-3] + "..."
+	if limit > 1 && len(msg) > limit {
+		return msg[0:limit-1] + "…"
 	}
 	return pad(msg, limit)
 }
