@@ -174,47 +174,27 @@ func (c *Client) GetV1(ctx context.Context, path string, headers Header) (*http.
 
 // Post sends POST request to v3 version of the jira api.
 func (c *Client) Post(ctx context.Context, path string, body []byte, headers Header) (*http.Response, error) {
-	res, err := c.request(ctx, http.MethodPost, c.server+baseURLv3+path, body, headers)
-	if err != nil {
-		return res, err
-	}
-	return res, err
+	return c.request(ctx, http.MethodPost, c.server+baseURLv3+path, body, headers)
 }
 
 // PostV2 sends POST request to v2 version of the jira api.
 func (c *Client) PostV2(ctx context.Context, path string, body []byte, headers Header) (*http.Response, error) {
-	res, err := c.request(ctx, http.MethodPost, c.server+baseURLv2+path, body, headers)
-	if err != nil {
-		return res, err
-	}
-	return res, err
+	return c.request(ctx, http.MethodPost, c.server+baseURLv2+path, body, headers)
 }
 
 // PostV1 sends POST request to v1 version of the jira api.
 func (c *Client) PostV1(ctx context.Context, path string, body []byte, headers Header) (*http.Response, error) {
-	res, err := c.request(ctx, http.MethodPost, c.server+baseURLv1+path, body, headers)
-	if err != nil {
-		return res, err
-	}
-	return res, err
+	return c.request(ctx, http.MethodPost, c.server+baseURLv1+path, body, headers)
 }
 
 // Put sends PUT request to v3 version of the jira api.
 func (c *Client) Put(ctx context.Context, path string, body []byte, headers Header) (*http.Response, error) {
-	res, err := c.request(ctx, http.MethodPut, c.server+baseURLv3+path, body, headers)
-	if err != nil {
-		return res, err
-	}
-	return res, err
+	return c.request(ctx, http.MethodPut, c.server+baseURLv3+path, body, headers)
 }
 
 // PutV2 sends PUT request to v2 version of the jira api.
 func (c *Client) PutV2(ctx context.Context, path string, body []byte, headers Header) (*http.Response, error) {
-	res, err := c.request(ctx, http.MethodPut, c.server+baseURLv2+path, body, headers)
-	if err != nil {
-		return res, err
-	}
-	return res, err
+	return c.request(ctx, http.MethodPut, c.server+baseURLv2+path, body, headers)
 }
 
 // DeleteV2 sends DELETE request to v2 version of the jira api.
@@ -250,9 +230,7 @@ func (c *Client) request(ctx context.Context, method, endpoint string, body []by
 		req.SetBasicAuth(c.login, c.token)
 	}
 
-	res, err = c.transport.RoundTrip(req.WithContext(ctx))
-
-	return res, err
+	return c.transport.RoundTrip(req.WithContext(ctx))
 }
 
 func dump(req *http.Request, res *http.Response) {
