@@ -299,16 +299,22 @@ func (c *Client) AddIssueComment(key, comment string) error {
 }
 
 type issueWorklogRequest struct {
+	Started   string `json:"started,omitempty"`
 	TimeSpent string `json:"timeSpent"`
 	Comment   string `json:"comment"`
 }
 
 // AddIssueWorklog adds worklog to an issue using POST /issue/{key}/worklog endpoint.
-func (c *Client) AddIssueWorklog(key, timeSpent, comment string) error {
-	body, err := json.Marshal(&issueWorklogRequest{
+// Leave param `started` empty to use the server's current datetime as start date.
+func (c *Client) AddIssueWorklog(key, started, timeSpent, comment string) error {
+	worklogReq := issueWorklogRequest{
 		TimeSpent: timeSpent,
 		Comment:   md.ToJiraMD(comment),
-	})
+	}
+	if started != "" {
+		worklogReq.Started = started
+	}
+	body, err := json.Marshal(&worklogReq)
 	if err != nil {
 		return err
 	}
@@ -332,6 +338,31 @@ func (c *Client) AddIssueWorklog(key, timeSpent, comment string) error {
 	return nil
 }
 
+// GetField gets all fields configured for a Jira instance using GET /field endpiont.
+func (c *Client) GetField() ([]*Field, error) {
+	res, err := c.GetV2(context.Background(), "/field", Header{
+		"Accept":       "application/json",
+		"Content-Type": "application/json",
+	})
+	if err != nil {
+		return nil, err
+	}
+	if res == nil {
+		return nil, ErrEmptyResponse
+	}
+	defer func() { _ = res.Body.Close() }()
+
+	if res.StatusCode != http.StatusOK {
+		return nil, formatUnexpectedResponse(res)
+	}
+
+	var out []*Field
+
+	err = json.NewDecoder(res.Body).Decode(&out)
+
+	return out, err
+}
+
 func ifaceToADF(v interface{}) *adf.ADF {
 	if v == nil {
 		return nil
@@ -349,3 +380,42 @@ func ifaceToADF(v interface{}) *adf.ADF {
 
 	return doc
 }
+
+type remotelinkRequest struct {
+	RemoteObject struct {
+		URL   string `json:"url"`
+		Title string `json:"title"`
+	} `json:"object"`
+}
+
+// RemoteLinkIssue adds a remote link to an issue using POST /issue/{issueId}/remotelink endpoint.
+func (c *Client) RemoteLinkIssue(issueID, title, url string) error {
+	body, err := json.Marshal(remotelinkRequest{
+		RemoteObject: struct {
+			URL   string `json:"url"`
+			Title string `json:"title"`
+		}{Title: title, URL: url},
+	})
+	if err != nil {
+		return err
+	}
+
+	path := fmt.Sprintf("/issue/%s/remotelink", issueID)
+
+	res, err := c.PostV2(context.Background(), path, body, Header{
+		"Accept":       "application/json",
+		"Content-Type": "application/json",
+	})
+	if err != nil {
+		return err
+	}
+	if res == nil {
+		return ErrEmptyResponse
+	}
+	defer func() { _ = res.Body.Close() }()
+
+	if res.StatusCode != http.StatusCreated {
+		return formatUnexpectedResponse(res)
+	}
+	return nil
+}
