@@ -10,8 +10,8 @@ import (
 
 	"github.com/cli/safeexec"
 	"github.com/gdamore/tcell/v2"
-
-	"github.com/ankitpokhrel/jira-cli/pkg/tui/primitive"
+	"github.com/mattn/go-isatty"
+	"github.com/rivo/tview"
 )
 
 func pad(in string, n uint) string {
@@ -48,12 +48,11 @@ func splitText(s string) []string {
 	return lines
 }
 
-func getInfoModal() *primitive.Modal {
-	return primitive.NewModal().
+func getInfoModal() *tview.Modal {
+	return tview.NewModal().
 		SetText("\n\nProcessing. Please wait...").
 		SetBackgroundColor(tcell.ColorSpecial).
-		SetTextColor(tcell.ColorDefault).
-		SetBorderColor(tcell.ColorDefault)
+		SetTextColor(tcell.ColorDefault)
 }
 
 // IsDumbTerminal checks TERM environment variable and returns true if it is set to dumb.
@@ -65,6 +64,11 @@ func IsDumbTerminal() bool {
 	return term == "" || term == "dumb"
 }
 
+// IsNotTTY returns true if the stdout file descriptor is not a TTY.
+func IsNotTTY() bool {
+	return !isatty.IsTerminal(os.Stdout.Fd())
+}
+
 // GetPager returns configured pager.
 func GetPager() string {
 	if runtime.GOOS == "windows" {
